@@ -49,11 +49,10 @@ class PubSub(object):
             self.kafka_replication_factor = kafka_replication_factor
             self.kafka_partitions = kafka_partitions
             self.kafka_poll_timeout = kafka_poll_timeout
-            self.kafka_emit_prefix = kafka_emit_prefix
-            self.kafka_receive_prefix = kafka_receive_prefix
+            self.kafka_emit_prefixes = kafka_emit_prefix.split(",")
+            self.kafka_receive_prefixes = kafka_receive_prefix.split(",")
             self._kafka_producer = None
             self._kafka_consumer = None
-            self.create_kafka_topics()
 
     def get_kafka_producer(self):
         # We don't want to establish a connection everytime we need to use the producer
@@ -88,8 +87,9 @@ class PubSub(object):
             auto_offset_reset="earliest",
         )
 
-    def create_kafka_topics(self):
-        if not self.kafka_topics:
+    def create_kafka_topics(self, topics):
+        if not topics:
+            logger.info("Unable to find kafka topics, skipping creation")
             return
 
         client = KafkaClient(bootstrap_servers=self.kafka_brokers)
@@ -101,16 +101,16 @@ class PubSub(object):
         already_topics = metadata.topics()
 
         new_topic_list = list()
-        for topic in self.kafka_topics:
-            for topic_prefix in self.kafka_receive_prefix:
-                custom_topic = "%s%s" % (topic_prefix, topic)
-                if custom_topic not in already_topics:
-                    new_topic_list.append(NewTopic(
-                        name=topic,
-                        num_partitions=self.kafka_partitions,
-                        replication_factor=self.kafka_replication_factor,
-                    ))
-                    logger.info("Creating new kafka topic %s" % (topic, ))
+        for topic in topics:
+            if topic not in already_topics:
+                new_topic_list.append(NewTopic(
+                    name=topic,
+                    num_partitions=self.kafka_partitions,
+                    replication_factor=self.kafka_replication_factor,
+                ))
+                logger.info("Creating new kafka topic %s" % (topic, ))
+            else:
+                logger.info("Kafka topic %s already exists" % (topic,))
 
         kafka_admin.create_topics(new_topic_list)
 
@@ -128,11 +128,12 @@ class PubSub(object):
         self.pubsub.close()
 
         if self.enable_kafka:
-            formatted_event = "%s%s" % (self.kafka_emit_prefix, event)
-            kafka_producer = self.get_kafka_producer()
-            future = kafka_producer.send(formatted_event, message_str.encode("utf-8"))
-            # Should we wait and make sure it is sent ?
-            future.get(timeout=60)
+            for emit_prefix in self.kafka_emit_prefixes:
+                formatted_event = "%s%s" % (emit_prefix, event)
+                kafka_producer = self.get_kafka_producer()
+                future = kafka_producer.send(formatted_event, message_str.encode("utf-8"))
+                # Should we wait and make sure it is sent ?
+                future.get(timeout=60)
 
     def receive(self, listeners, restart_connections=None):
         # We cannot have both (Redis & Kafka) consumers running at the same time, they will block the
@@ -145,11 +146,15 @@ class PubSub(object):
     def receive_kafka(self, listeners):
         new_listeners = dict()
         for k, v in listeners.items():
-            for prefix in self.kafka_receive_prefix:
+            for prefix in self.kafka_receive_prefixes:
                 new_listeners["%s%s" % (prefix, k)] = v
 
+        listeners_prefixes = list(new_listeners.keys())
+
+        self.create_kafka_topics(listeners_prefixes)
         consumer = self.get_kafka_consumer()
-        consumer.subscribe(list(new_listeners.keys()))
+        consumer.subscribe(listeners_prefixes)
+
         while True:
             # poll accepts timeout_ms and it will keep polling new records and batching them until timeout is met
             message = consumer.poll(self.kafka_poll_timeout)
